<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

    <!-- Declaration of parameters -->

    <!-- what is this?  the id of the portfolio we are tryiong to view? -->
    <xsl:param name="id"/>

    <!-- name of the student making this portfolio -->
    <xsl:param name="ownerName">
        <xsl:call-template name="portfolioOwnerName"/>
    </xsl:param>

    <!-- name of page to show for that stage -->
    <xsl:param name="page"/>

    <!-- name of stage of program -->
    <xsl:param name="stage"/>

    <!-- the id of the artifact to view -->
    <xsl:param name="artifactId"/>

    <!-- the id of the sakai tool placement-->
    <xsl:param name="sakai.tool.placement.id"/>

    <!-- Declare output method -->
    <xsl:output method="html" indent="yes"/>

    <!-- Main Template outputs our page -->
    <xsl:template match="/">
            <xsl:choose>
            <xsl:when test="$page=foo">
                <!-- call page 2 template --> Page 2 Content </xsl:when>
            <xsl:when test="$page=bar">
                <!-- call page 3 template --> Page 3 Content </xsl:when>
            <xsl:otherwise>
                <!-- call main (page 1) template -->
                <xsl:call-template name="pageOutline"/>                    
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- pageOutline template outputs our HTML page -->
    <xsl:template name="pageOutline">
        <xsl:param name="heading"/>
        <xsl:param name="mainContent"/>

        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <title>SOE Portfolio for <xsl:value-of select="$ownerName"/></title>
                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">
                        <xsl:value-of select="/ospiPresentation/presentationFiles/style/artifact/fileArtifact/uri"/>
                    </xsl:attribute>
                </link>
            </head>
            <body>
                <div class="wrapper1">

                    <!-- Header contains students name and SOE logo -->
                    <div class="header">
                        <a>
                            <xsl:attribute name="href">
                                <xsl:text disable-output-escaping="yes">viewPresentation.osp?id=</xsl:text>
                                <xsl:value-of select="$id"/>
                                <xsl:text disable-output-escaping="yes">&amp;page=&amp;stage=</xsl:text>
                                <xsl:text disable-output-escaping="yes">&amp;sakai.tool.placement.id=</xsl:text>
                                <xsl:value-of select="$sakai.tool.placement.id"/>
                            </xsl:attribute>
                            <img>
                                <xsl:attribute name="src">
                                    <xsl:value-of select="/ospiPresentation/presentationFiles/logo/artifact/fileArtifact/uri"/>
                                </xsl:attribute>
                                <xsl:attribute name="alt">Syracuse University School of Education</xsl:attribute>
                                <xsl:attribute name="height">78</xsl:attribute>
                                <xsl:attribute name="width">309</xsl:attribute>

                            </img>
                        </a>
                        <a>
                            <xsl:attribute name="href">
                                <xsl:text disable-output-escaping="yes">viewPresentation.osp?id=</xsl:text>
                                <xsl:value-of select="$id"/>
                                <xsl:text disable-output-escaping="yes">&amp;page=&amp;stage=</xsl:text>
                                <xsl:text disable-output-escaping="yes">&amp;sakai.tool.placement.id=</xsl:text>
                                <xsl:value-of select="$sakai.tool.placement.id"/>
                            </xsl:attribute>
                            <h1>
                                <xsl:value-of select="$ownerName"/>
                            </h1>
                        </a>

                        <div class="clearB">&#160;</div>
                    </div>
                    <!-- Breadcrumb trail -->
                    <!-- this needs to be dynamically generated -->
                    <div class="bread">
                        <ul>
                            <xsl:if test="($page!='My Emerging Theory') and ($page!='A History of Reflection')">
                                <xsl:choose>
                                    <xsl:when test="$stage='Pre-candidacy'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Pre-candidacy</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                    <xsl:when test="$stage='Block 1'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Block 1</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                    <xsl:when test="$stage='Block 2'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Block 2</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                    <xsl:when test="$stage='Preliminary Exit'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Preliminary Exit</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                    <xsl:when test="$stage='Exit'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Exit</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                    <xsl:when test="$stage='Post-Exit'">
                                        <li>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="page">
                                                    <xsl:value-of select="$page"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="$stage"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">Post-Exit</xsl:with-param>
                                            </xsl:call-template>
                                        </li>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:if>

                            <xsl:choose>
                                <xsl:when test="$page='My Emerging Theory'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">My Emerging Theory</xsl:with-param>
                                            <xsl:with-param name="stage"/>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">My Emerging Theory</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='A History of Reflection'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">A History of Reflection</xsl:with-param>
                                            <xsl:with-param name="stage"/>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">A History of Reflection</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>

                                <xsl:when test="$page='Contact Information'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Contact Information</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Contact Information</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Emerging Theory'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Emerging Theory</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Emerging Theory</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Placements'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Placements</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Placements</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Critical Reflection and Explanation of Practice'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Critical Reflection and Explanation of Practice</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Critical Reflection and Explanation of Practice</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Content Knowledge'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Content Knowledge</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Content Knowledge</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Inclusive and Culturally Responsive Pedagogy'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Inclusive and Culturally Responsive Pedagogy</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Inclusive and Culturally Responsive Pedagogy</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Assessment of Student Learning'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Assessment of Student Learning</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Assessment of Student Learning</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>
                                <xsl:when test="$page='Professional Conduct and Collaboration'">
                                    <li>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">Professional Conduct and Collaboration</xsl:with-param>
                                            <xsl:with-param name="stage">
                                                <xsl:value-of select="$stage"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">Professional Conduct and Collaboration</xsl:with-param>
                                        </xsl:call-template>
                                    </li>
                                </xsl:when>

                            </xsl:choose>

                        </ul>
                    </div>
                    <!-- MainNavigation menu for navigating stages and history pages -->
                    <div class="mainNav">

                        <ul id="historyMenu">
                            <li>
                                <xsl:choose>
                                    <xsl:when test="$page='My Emerging Theory'">
                                        <xsl:attribute name="class">
                                            <xsl:text>current</xsl:text>
                                        </xsl:attribute>
                                        <xsl:text>My Emerging Theory</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">My Emerging Theory</xsl:with-param>
                                            <xsl:with-param name="stage"/>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">My Emerging Theory</xsl:with-param>
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </li>
                            <li>
                                <xsl:choose>
                                    <xsl:when test="$page='A History of Reflection'">
                                        <xsl:attribute name="class">
                                            <xsl:text>current</xsl:text>
                                        </xsl:attribute>
                                        <xsl:text>A History of Reflection</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="link">
                                            <xsl:with-param name="page">A History of Reflection</xsl:with-param>
                                            <xsl:with-param name="stage"/>
                                            <xsl:with-param name="sakai.tool.placement.id">
                                                <xsl:value-of select="$sakai.tool.placement.id"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="text">A History of Reflection</xsl:with-param>
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </li>
                        </ul>

                        <!-- dynamically build a menu from the matrix column names -->
                        <ul id="phaseMenu">
                            <xsl:for-each select="/ospiPresentation/matrix/artifact/scaffolding/levels/level">
                                <li>
                                    <xsl:choose>
                                        <xsl:when test="./description=$stage">
                                            <xsl:attribute name="class">
                                                <xsl:text>current</xsl:text>
                                            </xsl:attribute>
                                            <xsl:value-of select="description"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:call-template name="link">
                                                <xsl:with-param name="stage">
                                                    <xsl:value-of select="description"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="page">
                                                    <xsl:choose>
                                                        <xsl:when test="($page='My Emerging Theory') or ($page='A History of Reflection')">
                                                            <xsl:text>Contact Information</xsl:text>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:value-of select="$page"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:with-param>
                                                <xsl:with-param name="sakai.tool.placement.id">
                                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                                </xsl:with-param>
                                                <xsl:with-param name="text">
                                                    <xsl:value-of select="description"/>
                                                </xsl:with-param>
                                            </xsl:call-template>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </li>
                            </xsl:for-each>
                        </ul>
                        <div class="clearB">&#160;</div>
                    </div>

                    <div class="contentWrapper">
                        <!-- Proficiency menu -->
                        <xsl:choose>
                            <xsl:when test="$stage!=''">
                                <div class="leftNav">
                                    <h3>About me</h3>
                                    <ul>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Contact Information'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Contact Information</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Contact Information</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Emerging Theory'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Emerging Theory</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Emerging Theory</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Placements'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Placements</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Placements</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                    </ul>
                                    <h3>Proficiencies</h3>
                                    <ul>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Critical Reflection and Explanation of Practice'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Critical Reflection and Explanation of Practice</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Critical Reflection and Explanation of Practice</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Content Knowledge'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Content Knowledge</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Content Knowledge</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Inclusive and Culturally Responsive Pedagogy'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Inclusive and Culturally Responsive Pedagogy</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Inclusive and Culturally Responsive Pedagogy</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Assessment of Student Learning'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Assessment of Student Learning</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Assessment of Student Learning</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                        <li>
                                            <xsl:choose>
                                                <xsl:when test="$page='Professional Conduct and Collaboration'">
                                                    <xsl:attribute name="class">
                                                        <xsl:text>current</xsl:text>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$page"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="link">
                                                        <xsl:with-param name="page">Professional Conduct and Collaboration</xsl:with-param>
                                                        <xsl:with-param name="stage">
                                                            <xsl:value-of select="$stage"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="sakai.tool.placement.id">
                                                            <xsl:value-of select="$sakai.tool.placement.id"/>
                                                        </xsl:with-param>
                                                        <xsl:with-param name="text">Professional Conduct and Collaboration</xsl:with-param>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </li>
                                    </ul>
                                </div>
                            </xsl:when>
                        </xsl:choose>


                        <!-- Main content area -->
                        <div>
                            <xsl:choose>
                                <xsl:when
                                    test="($page='Critical Reflection and Explanation of Practice') 
                                    or ($page='Content Knowledge') 
                                    or ($page='Inclusive and Culturally Responsive Pedagogy') 
                                    or ($page='Assessment of Student Learning') 
                                    or ($page='Professional Conduct and Collaboration')">
                                    <xsl:attribute name="id">mainContentWithEvidence</xsl:attribute>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:attribute name="id">mainContent</xsl:attribute>
                                </xsl:otherwise>
                            </xsl:choose>

                            <xsl:choose>
                                <xsl:when test="$page='pt'">
                                    <xsl:copy-of select="*"/>
                                </xsl:when>
                            </xsl:choose>

                            <xsl:call-template name="proficiencyBody"/>
                        </div>

                        <!-- show evidence menu if there is a stage set -->
                        <xsl:choose>
                            <xsl:when
                                test="($page='Critical Reflection and Explanation of Practice') 
                                or ($page='Content Knowledge') 
                                or ($page='Inclusive and Culturally Responsive Pedagogy') 
                                or ($page='Assessment of Student Learning') 
                                or ($page='Professional Conduct and Collaboration')">
                                <div id="evidenceMenu">
                                    <h3>Supporting Evidence</h3>
                                    <div class="evidenceLink">
                                        <xsl:call-template name="proficiencySupporting"/>
                                    </div>
                                </div>
                            </xsl:when>
                        </xsl:choose>
                    </div>
                    <!-- end of contentWrapper -->

                    <!-- Footer -->
                    <div class="footer">
                        <ul>
                            <li> School of Education </li>
                            <li> Syracuse University </li>
                        </ul>
                    </div>
                    <!-- end of stageMenu -->

                </div>
                <!-- end of wrapper1 -->
            </body>
        </html>
    </xsl:template>

    <xsl:template name="link">
        <xsl:param name="page"/>
        <xsl:param name="stage"/>
        <xsl:param name="text"/>
        <xsl:param name="artifactId"/>
        <xsl:param name="sakai.tool.placement.id"/>
        <xsl:param name="thumnail"/>
        <a>
            <xsl:attribute name="href">
                <xsl:text disable-output-escaping="yes">viewPresentation.osp?id=</xsl:text>
                <xsl:value-of select="$id"/>
                <xsl:text disable-output-escaping="yes">&amp;page=</xsl:text>
                <xsl:value-of select="$page"/>
                <xsl:text disable-output-escaping="yes">&amp;stage=</xsl:text>
                <xsl:value-of select="$stage"/>
                <xsl:text disable-output-escaping="yes">&amp;artifactId=</xsl:text>
                <xsl:value-of select="$artifactId"/>
                <xsl:text disable-output-escaping="yes">&amp;sakai.tool.placement.id=</xsl:text>
                <xsl:value-of select="$sakai.tool.placement.id"/>
            </xsl:attribute>
            <xsl:if test="$thumnail != ''">
                <img>
                    <xsl:attribute name="src">
                        <xsl:text>/access/content</xsl:text>
                        <xsl:value-of select="$thumnail"/>
                    </xsl:attribute>
                    <xsl:attribute name="alt">
                        <xsl:value-of select="artifact/structuredData/artifactPage/pageName"/>
                    </xsl:attribute>
                </img>
                <br/>
            </xsl:if>
            <xsl:value-of select="$text"/>
        </a>
    </xsl:template>

    <!-- retrieve portfolio owner name -->
    <xsl:template name="portfolioOwnerName">
        <xsl:choose>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Post-Exit, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"
                />
            </xsl:when>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Exit, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Exit, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Exit, Background']"
                />
            </xsl:when>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background']"
                />
            </xsl:when>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 2, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Block 2, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 2, Background']"
                />
            </xsl:when>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 1, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Block 1, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 1, Background']"
                />
            </xsl:when>
            <xsl:when
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background'])">
                <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"
                />&#160; <xsl:value-of
                    select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"
                />
            </xsl:when>
            <xsl:otherwise> </xsl:otherwise>
        </xsl:choose>


    </xsl:template>

    <!-- main content -->
    <xsl:template name="proficiencyBody">

        <xsl:if test="($page='My Emerging Theory')">
            <xsl:call-template name="MyEmergingTheory"/>
        </xsl:if>
        <xsl:if test="($page='A History of Reflection')">
            <xsl:call-template name="HistoryOfReflection"/>
        </xsl:if>
        <xsl:if test="($page='') or ($page='Contact Information')">
            <xsl:choose>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Post-Exit, Background']">
                    <h2>Post-Exit Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Exit, Background']">
                    <h2>Exit Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Exit, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']">
                    <h2>Preliminary-Exit Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Preliminary-Exit, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 2, Background']">
                    <h2>Block 2 Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Block 2, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 1, Background']">
                    <h2>Block 1 Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Block 1, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                <xsl:when
                    test="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']">
                    <h2>Precandidacy Portfolio Review</h2>
                    <xsl:call-template name="contactInformation">
                        <xsl:with-param name="firstName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/firstName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="lastName">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="email">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/email[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="phoneNumber">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/phoneNumber[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="photoUpload">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/photoUpload[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="programOfStudy">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/programOfStudy[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>
                        <xsl:with-param name="certificationAreas">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/certificationAreas[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>           
                        <xsl:with-param name="expectedGraduationDate">
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/expectedGraduationDate[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/> 
                        </xsl:with-param>           
                    </xsl:call-template>
                </xsl:when>
                
            </xsl:choose>
            
            <!--<xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Exit, Background'])">
                <xsl:template match="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/[../../../../../../scaffoldingCell/title='Exit, Background']">
                    <xsl:apply-templates select="."/>
                </xsl:template>                
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background'])">
                <xsl:apply-templates select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/[../../../../../../scaffoldingCell/title='Preliminary Exit, Background']"/>       
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 2, Background'])">
                <xsl:apply-templates select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/[../../../../../../scaffoldingCell/title='Block 2, Background']"/>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Block 1, Background'])">
                <xsl:apply-templates select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/[../../../../../../scaffoldingCell/title='Block 1, Background']"/>            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/lastName[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background'])">
                <xsl:apply-templates select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/contactInformation/[../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"/>
            </xsl:if>-->

        </xsl:if>

        <!-- main content: stage+page -->
        <xsl:for-each select="/ospiPresentation/matrix/artifact/cells/cell">

            <xsl:if
                test="((scaffoldingCell/title='Pre-candidacy, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Pre-candidacy, Proficiency 2') and ($page='Content Knowledge') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Pre-candidacy, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Pre-candidacy, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Pre-candidacy, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Pre-candidacy'))
                    
                    or ((scaffoldingCell/title='Block 1, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 1, Proficiency 2') and ($page='Content Knowledge') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 1, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 1, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 1, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Block 1'))
                    
                    or ((scaffoldingCell/title='Block 2, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Block 2, Proficiency 2') and ($page='Content Knowledge') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Block 2, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Block 2, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Block 2, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Block 2'))
                    
                    or ((scaffoldingCell/title='Preliminary Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Preliminary Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Preliminary Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Preliminary Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Preliminary Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Preliminary Exit'))
                    
                    or ((scaffoldingCell/title='Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Exit'))
                    
                    or ((scaffoldingCell/title='Post-Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Post-Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Post-Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Post-Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Post-Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Post-Exit'))
                    
                    ">
                <xsl:if test="($artifactId='')">
                    <div>
                        <xsl:for-each select="wizardPage/reflections/reflection">
                            <h3>Introduction:</h3>
                            <xsl:value-of select="artifact/structuredData/reflection/proficiencyStatement/choice" disable-output-escaping="yes"/>
                            <h3>Reflection:</h3>
                            <p>
                                <xsl:value-of select="artifact/structuredData/reflection/description" disable-output-escaping="yes"/>
                            </p>
                        </xsl:for-each>
                    </div>
                </xsl:if>
                <xsl:if test="($artifactId!='')">
                    <xsl:for-each select="wizardPage/pageForms/pageForm">

                        <xsl:if test="artifact/metaData/id=$artifactId">
                            <p>
                                <h2>
                                    <xsl:value-of select="artifact/structuredData/artifactPage/pageName" disable-output-escaping="yes"/>
                                </h2>
                            </p>
                            <p>
                                <h3>Summary</h3>
                            </p>
                            <p>
                                <xsl:value-of select="artifact/structuredData/artifactPage/narrative" disable-output-escaping="yes"/>
                            </p>
                            <h3>Artifact(s)</h3>
                            <p>
                                <xsl:value-of select="artifact/structuredData/artifactPage/artifacts" disable-output-escaping="yes"/>
                            </p>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:if>
            </xsl:if>

            <xsl:if
                test="((scaffoldingCell/title='Pre-candidacy, Background') and ($page='Emerging Theory') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Block 1, Background') and ($page='Emerging Theory') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 2, Background') and ($page='Emerging Theory') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Preliminary Exit, Background') and ($page='Emerging Theory') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Exit, Background') and ($page='Emerging Theory') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Background') and ($page='Emerging Theory') and ($stage='Post-Exit'))
                    
                    ">

                <xsl:for-each select="wizardPage/pageForms/pageForm">
                    <xsl:if test="artifact/structuredData/emergingPhilosophy/description">
                        <h2>Emerging Theory</h2>
                        <xsl:value-of select="artifact/structuredData/emergingPhilosophy/description" disable-output-escaping="yes"/>
                    </xsl:if>
                </xsl:for-each>
            </xsl:if>

            <xsl:if
                test="((scaffoldingCell/title='Pre-candidacy, Background') and ($page='Placements') and ($stage='Pre-candidacy'))
                    or ((scaffoldingCell/title='Block 1, Background') and ($page='Placements') and ($stage='Block 1'))
                    or ((scaffoldingCell/title='Block 2, Background') and ($page='Placements') and ($stage='Block 2'))
                    or ((scaffoldingCell/title='Preliminary Exit, Background') and ($page='Placements') and ($stage='Preliminary Exit'))
                    or ((scaffoldingCell/title='Exit, Background') and ($page='Placements') and ($stage='Exit'))
                    or ((scaffoldingCell/title='Post-Exit, Background') and ($page='Placements') and ($stage='Post-Exit'))                   
                    ">

                <xsl:for-each select="wizardPage/pageForms/pageForm">
                    <xsl:if test="artifact/structuredData/placement/placementDescription">
                        <h2>Placements</h2>
                        <xsl:value-of select="artifact/structuredData/placement/placementDescription" disable-output-escaping="yes"/>
                    </xsl:if>
                </xsl:for-each>
            </xsl:if>
        </xsl:for-each>

    </xsl:template>

    <xsl:template name="contactInformation">
        <xsl:param name="firstName"/>
        <xsl:param name="lastName"/>
        <xsl:param name="email"/>
        <xsl:param name="phoneNumber"/>
        <xsl:param name="photoUpload"/>
        <xsl:param name="programOfStudy"/>
        <xsl:param name="certificationAreas"/>
        <xsl:param name="expectedGraduationDate"/>
        <div class="personalInfo" style="display: inline; float: left; margin-left: 20%">
            <table border="0" cellpadding="2">
                <tr>
                    <th align="right">Name:</th>
                    <td align="left">
                        <xsl:value-of select="$firstName"/>
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="$lastName"/>
                    </td>
                </tr>
                <tr align="right">
                    <th>Email:</th>
                    <td align="left">
                        <xsl:value-of select="$email"/>
                    </td>
                </tr>                
                <tr align="right">
                    <th>Phone:</th>
                    <td align="left">
                        <xsl:value-of select="$phoneNumber"/>
                    </td>
                </tr>
                <tr align="right">
                    <th>Program:</th>
                    <td align="left">
                        <xsl:value-of select="$programOfStudy"/>
                    </td>
                </tr>
                <tr align="right">
                    <th>Certification Areas:</th>
                    <td align="left">
                        <xsl:value-of select="$certificationAreas"/>
                    </td>
                </tr>
                <tr align="right">
                    <th>Graduation Date:</th>
                    <td align="left">
                        <xsl:value-of select="$expectedGraduationDate"/>
                    </td>
                </tr>
            </table>
        </div>
        <img style="display: inline; float: left; margin-left: 3em">
            <xsl:attribute name="src">
                <xsl:text>/access/content/</xsl:text><xsl:value-of select="$photoUpload"/>
            </xsl:attribute>
            <xsl:attribute name="alt">
                <xsl:value-of select="$firstName"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="$lastName"/>
            </xsl:attribute>
        </img>
            
    </xsl:template>

    <!-- main content:  My Emerging Theory -->
    <xsl:template name="MyEmergingTheory">
        <h1>My Emerging Theory</h1>
        <div class="indent">
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Post-Exit, Background'])">

                <p>
                    <h2>Post-Exit Emerging Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Post-Exit, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Exit, Background'])">
                <p>
                    <h2>Exit Emerging Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Exit, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background'])">
                <p>
                    <h2>Preliminary Exit Emerging Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Block 2, Background'])">
                <p>
                    <h2>Block 2 Emerging Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Block 2, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Block 1, Background'])">
                <p>
                    <h2>Block 1 Emerging Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Block 1, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
            <xsl:if
                test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background'])">
                <p>
                    <h2>Pre-candidacy Theory</h2>
                </p>
                <div class="indent">
                    <p>
                        <xsl:value-of
                            select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/pageForms/pageForm/artifact/structuredData/emergingPhilosophy/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Background']"
                            disable-output-escaping="yes"/>
                    </p>
                </div>
            </xsl:if>
        </div>
    </xsl:template>

    <!-- main content:  History Of Reflection -->
    <xsl:template name="HistoryOfReflection">
        <h1>History of Reflection</h1>
        <div class="indent">
            <!-- Proficiency 1 -->
            <p>
                <h2>Critical Reflection and Explanation of Practice</h2>
            </p>
            <div class="indent">
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 1'])">
                    <p>
                        <h3>Post-Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 1'])">
                    <p>
                        <h3>Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 1'])">
                    <p>
                        <h3>Preliminary Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 1'])">
                    <p>
                        <h3>Block 2</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 1'])">
                    <p>
                        <h3>Block 1</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 1'])">
                    <p>
                        <h3>Pre-candidacy</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 1']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
            </div>

            <!-- Proficiency 2 -->
            <p>
                <h2>Content Knowledge</h2>
            </p>
            <div class="indent">
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 2'])">
                    <p>
                        <h3>Post-Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 2'])">
                    <p>
                        <h3>Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 2'])">
                    <p>
                        <h3>Preliminary Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 2'])">
                    <p>
                        <h3>Block 2</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 2'])">
                    <p>
                        <h3>Block 1</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 2'])">
                    <p>
                        <h3>Pre-candidacy</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 2']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
            </div>
            <!-- Proficiency 3 -->
            <p>
                <h2>Inclusive and Culturally Responsive Pedagogy</h2>
            </p>
            <div class="indent">
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 3'])">
                    <p>
                        <h3>Post-Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 3'])">
                    <p>
                        <h3>Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 3'])">
                    <p>
                        <h3>Preliminary Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 3'])">
                    <p>
                        <h3>Block 2</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 3'])">
                    <p>
                        <h3>Block 1</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 3'])">
                    <p>
                        <h3>Pre-candidacy</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 3']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
            </div>
            <!-- Proficiency 4 -->
            <p>
                <h2>Assessment of Student Learning</h2>
            </p>
            <div class="indent">
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 4'])">
                    <p>
                        <h3>Post-Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 4'])">
                    <p>
                        <h3>Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 4'])">
                    <p>
                        <h3>Preliminary Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 4'])">
                    <p>
                        <h3>Block 2</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 4'])">
                    <p>
                        <h3>Block 1</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 4'])">
                    <p>
                        <h3>Pre-candidacy</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 4']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
            </div>
            <!-- Proficiency 5 -->
            <p>
                <h2>Professional Conduct and Collaboration</h2>
            </p>
            <div class="indent">
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 5'])">
                    <p>
                        <h3>Post-Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Post-Exit, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 5'])">
                    <p>
                        <h3>Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Exit, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 5'])">
                    <p>
                        <h3>Preliminary Exit</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Preliminary Exit, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 5'])">
                    <p>
                        <h3>Block 2</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 2, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 5'])">
                    <p>
                        <h3>Block 1</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Block 1, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
                <xsl:if
                    test="(/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 5'])">
                    <p>
                        <h3>Pre-candidacy</h3>
                    </p>
                    <div class="indent">
                        <p>
                            <xsl:value-of
                                select="/ospiPresentation/matrix/artifact/cells/cell/wizardPage/reflections/reflection/artifact/structuredData/reflection/description[../../../../../../../scaffoldingCell/title='Pre-candidacy, Proficiency 5']"
                                disable-output-escaping="yes"/>
                        </p>
                    </div>
                </xsl:if>
            </div>
        </div>
    </xsl:template>

    <!-- Supporting Evidence -->
    <xsl:template name="proficiencySupporting">

        <div>
            <xsl:for-each select="/ospiPresentation/matrix/artifact/cells/cell">

                <xsl:if
                    test="((scaffoldingCell/title='Pre-candidacy, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Pre-candidacy'))
                or ((scaffoldingCell/title='Pre-candidacy, Proficiency 2') and ($page='Content Knowledge') and ($stage='Pre-candidacy'))
                or ((scaffoldingCell/title='Pre-candidacy, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Pre-candidacy'))
                or ((scaffoldingCell/title='Pre-candidacy, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Pre-candidacy'))
                or ((scaffoldingCell/title='Pre-candidacy, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Pre-candidacy'))
                
                or ((scaffoldingCell/title='Block 1, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Block 1'))
                or ((scaffoldingCell/title='Block 1, Proficiency 2') and ($page='Content Knowledge') and ($stage='Block 1'))
                or ((scaffoldingCell/title='Block 1, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Block 1'))
                or ((scaffoldingCell/title='Block 1, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Block 1'))
                or ((scaffoldingCell/title='Block 1, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Block 1'))
                
                or ((scaffoldingCell/title='Block 2, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Block 2'))
                or ((scaffoldingCell/title='Block 2, Proficiency 2') and ($page='Content Knowledge') and ($stage='Block 2'))
                or ((scaffoldingCell/title='Block 2, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Block 2'))
                or ((scaffoldingCell/title='Block 2, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Block 2'))
                or ((scaffoldingCell/title='Block 2, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Block 2'))
                
                or ((scaffoldingCell/title='Preliminary Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Preliminary Exit'))
                or ((scaffoldingCell/title='Preliminary Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Preliminary Exit'))
                or ((scaffoldingCell/title='Preliminary Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Preliminary Exit'))
                or ((scaffoldingCell/title='Preliminary Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Preliminary Exit'))
                or ((scaffoldingCell/title='Preliminary Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Preliminary Exit'))
                
                or ((scaffoldingCell/title='Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Exit'))
                or ((scaffoldingCell/title='Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Exit'))
                or ((scaffoldingCell/title='Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Exit'))
                or ((scaffoldingCell/title='Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Exit'))
                or ((scaffoldingCell/title='Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Exit'))
                
                or ((scaffoldingCell/title='Post-Exit, Proficiency 1') and ($page='Critical Reflection and Explanation of Practice') and ($stage='Post-Exit'))
                or ((scaffoldingCell/title='Post-Exit, Proficiency 2') and ($page='Content Knowledge') and ($stage='Post-Exit'))
                or ((scaffoldingCell/title='Post-Exit, Proficiency 3') and ($page='Inclusive and Culturally Responsive Pedagogy') and ($stage='Post-Exit'))
                or ((scaffoldingCell/title='Post-Exit, Proficiency 4') and ($page='Assessment of Student Learning') and ($stage='Post-Exit'))
                or ((scaffoldingCell/title='Post-Exit, Proficiency 5') and ($page='Professional Conduct and Collaboration') and ($stage='Post-Exit'))

                ">
                    <xsl:for-each select="wizardPage/pageForms/pageForm">
                        <xsl:sort select="artifact/structuredData/artifactPage/pageName"/>
                        <div class="artifacts">
                            <xsl:call-template name="link">
                                <xsl:with-param name="page">
                                    <xsl:value-of select="$page"/>
                                </xsl:with-param>
                                <xsl:with-param name="stage">
                                    <xsl:value-of select="$stage"/>
                                </xsl:with-param>
                                <xsl:with-param name="sakai.tool.placement.id">
                                    <xsl:value-of select="$sakai.tool.placement.id"/>
                                </xsl:with-param>
                                <xsl:with-param name="artifactId">
                                    <xsl:value-of select="artifact/metaData/id"/>
                                </xsl:with-param>
                                <xsl:with-param name="text">

                                    <xsl:value-of select="artifact/structuredData/artifactPage/pageName"/>
                                </xsl:with-param>
                                <xsl:with-param name="thumnail">
                                    <xsl:if test="artifact/structuredData/artifactPage/thumbnailload">
                                        <xsl:value-of select="artifact/structuredData/artifactPage/thumbnailload"/>
                                    </xsl:if>
                                </xsl:with-param>
                            </xsl:call-template>

                        </div>
                        <hr/>
                    </xsl:for-each>
                </xsl:if>
            </xsl:for-each>
        </div>
    </xsl:template>

</xsl:stylesheet>
